/// <reference types="react" />
import { ValueType, NameType } from 'recharts/types/component/DefaultTooltipContent';
import { ContentType } from 'recharts/types/component/Tooltip';
import { FeatureCollection } from 'geojson';

interface ButtonProps {
    text: string;
    onClick: () => void;
    color: string;
}

declare const Button: ({ text, onClick, color }: ButtonProps) => JSX.Element;

interface MultiAreaChartLegend {
    height?: number;
    show: boolean;
}
interface MultiAreaChartXAxis {
    values: string[];
}
interface MultiAreaChartYAxis {
    min: number;
    max: number;
}
interface MultiAreaChartArea {
    label: string;
    key: string;
    stackIndex: number;
    stroke: string;
    fill: string;
    opacity: number;
    values: number[];
    dot?: boolean;
}
interface MultiAreaChartLine {
    label: string;
    key: string;
    stroke: string;
    width: number;
    opacity: number;
    values: number[];
    dot?: boolean;
}
interface MultiAreaChartData {
    xAxis: MultiAreaChartXAxis;
    yAxis?: MultiAreaChartYAxis;
    areas: MultiAreaChartArea[];
    lines?: MultiAreaChartLine[];
}
interface MultiAreaChartTooltip {
    active?: boolean;
    trigger?: "click" | "hover";
    customTooltip?: ContentType<ValueType, NameType>;
}
interface MultiAreaChartProps {
    data: MultiAreaChartData;
    legend: MultiAreaChartLegend;
    tooltip?: MultiAreaChartTooltip;
}

declare const MultiAreaChart: ({ data, legend, tooltip }: MultiAreaChartProps) => JSX.Element;

interface SlidingDateSelectorProps {
    minYear: number;
    maxYear: number;
    labelColor: string;
    primaryButtonColor?: string;
    primaryButtonSelectedColor?: string;
    secondaryButtonColor?: string;
    onDateUpdated: (date: SelectedDate) => void;
}
interface SelectedDate {
    day?: number;
    month?: number;
    year: number;
}

declare const SlidingDateSelector: ({ labelColor, maxYear, minYear, onDateUpdated, primaryButtonColor, primaryButtonSelectedColor, secondaryButtonColor }: SlidingDateSelectorProps) => JSX.Element;

interface MapProps {
    id: string;
    tileUrl?: string;
    height: string;
    width: string;
    center: number[];
    zoom: number;
    icons?: MapIcon[];
    controls?: MapControls;
    highlightArea?: MapHighlightArea;
}
interface MapIcon {
    name: string;
    position: number[];
    anchor?: number[];
    anchorXUnits: 'fraction' | 'pixels';
    anchorYUnits: 'fraction' | 'pixels';
    src: string;
    imgSize?: number[];
}
interface MapControls {
    showZoomButtons?: boolean;
}
interface MapHighlightArea {
    geoJson: FeatureCollection;
    strokeWidth: number;
    strokeColor: string;
    fillColor: string;
}

declare const Map: ({ id, height, width, center, zoom, icons, controls, tileUrl, highlightArea }: MapProps) => JSX.Element;

export { Button, Map, MultiAreaChart, SlidingDateSelector };
