import React from 'react'
import { ComponentStory, ComponentMeta } from '@storybook/react'
import { default as Map } from '../../components/Map'
import { MapHighlightArea } from '../../components/Map/Map.types'
import { lollandFeature } from './lollandGeoJson'

export default {
  title: 'Maps/Map',
  component: Map,
} as ComponentMeta<typeof Map>

const Template: ComponentStory<typeof Map> = (args) => 
  <div style={{ width: '100%', height: '600px' }}><Map {...args} /></div>

const srcWindmill: string = require('../../img/windmill.png')
const srcSolar: string = require('../../img/solar.png')

const highlightArea: MapHighlightArea = {
  geoJson: {
    type: 'FeatureCollection',
    features: [lollandFeature]
  },
  strokeColor: 'rgba(50, 50, 255, 0.7)',
  strokeWidth: 2,
  fillColor: 'rgba(255, 255, 255, 0.2)',
}

export const Default = Template.bind({})
Default.args = {
  id: 'default',
  height: '600px',
  width: '100%',
  center: [1130465.4095683543, 7588191.868079771],
  zoom: 11,
}

export const HighlightedAreaWithCustomTilesAndIcons = Template.bind({})
HighlightedAreaWithCustomTilesAndIcons.args = {
  id: 'highlightedAreaWithCustomTilesAndIcons',
  highlightArea: highlightArea,
  tileUrl: 'https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png',
  height: '600px',
  width: '100%',
  center: [1260965.4095683543, 7318491.868079771],
  zoom: 10,
  icons: [
    {
      name: 'windmill',
      position: [1280965.4095683543, 7318491.868079771],
      anchorXUnits: 'fraction',
      anchorYUnits: 'pixels',
      src: srcWindmill,
    },
    {
      name: 'solar',
      position: [1250965.4095683543, 7318491.868079771],
      anchorXUnits: 'fraction',
      anchorYUnits: 'pixels',
      src: srcSolar,
    },
  ],
  controls: {
    showZoomButtons: false,
  },
}
